@@ -1,6 +1,6 @@
 //-----------------------------------------------------------------------------
 //
-// kfountain - Partical Fountain Screen Saver for KDE 2
+// kfountain - Partical Fountain Screen Saver for KDE
 //
 // Copyright (c)  Ian Reinhart Geiser 2001
 //
@@ -14,7 +14,6 @@
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcolordialog.h>
-#include <kbuttonbox.h>
 #include <kcolorbutton.h>
 #include <kglobal.h>
 #include "fountain.h"
@@ -34,30 +33,43 @@
 #include <kstandarddirs.h>
 #include <math.h>
 #include <kmessagebox.h>
+#include <krandom.h>
 // libkscreensaver interface
-extern "C"
+class KFountainSaverInterface : public KScreenSaverInterface
 {
-	KDE_EXPORT const char *kss_applicationName = "kfountain.kss";
-	KDE_EXPORT const char *kss_description = I18N_NOOP( "Particle Fountain Screen Saver" );
-	KDE_EXPORT const char *kss_version = "2.2.0";
 
-	KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "kfountain.kss", "klock", ki18n( "Particle Fountain Screen Saver" ), "2.2.0", ki18n( "Particle Fountain Screen Saver" ) );
+    }
+
+
+	virtual KScreenSaver* create( WId id )
 	{
 		return new KFountainSaver( id );
 	}
 
-	KDE_EXPORT QDialog *kss_setup()
+	virtual QDialog* setup()
 	{
 		return new KFountainSetup();
 	}
+};
+
+int main( int argc, char *argv[] )
+{
+    KFountainSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 //-----------------------------------------------------------------------------
 // dialog to setup screen saver parameters
 //
-KFountainSetup::KFountainSetup( QWidget *parent, const char *name )
-	: SetupUi( parent, name, TRUE )
+KFountainSetup::KFountainSetup( QWidget *parent )
+	: QDialog( parent)
 {
+	setupUi(this);
+	setModal(true);
 	readSettings();
 
 	//QLabel *label;
@@ -77,7 +89,12 @@ KFountainSetup::KFountainSetup( QWidget *parent, const char *name )
 
 	//preview = new QWidget( this );
 	preview->setFixedSize( 220, 170 );
-	preview->setBackgroundColor( black );
+        {
+            QPalette palette;
+            palette.setColor( preview->backgroundRole(), Qt::black );
+            preview->setPalette( palette );
+	    preview->setAutoFillBackground(true);
+        }
 	preview->show();    // otherwise saver does not get correct size
 	saver = new KFountainSaver( preview->winId() );
 	//tl1->addWidget(preview);
@@ -96,42 +113,37 @@ KFountainSetup::KFountainSetup( QWidget *parent, const char *name )
 // read settings from config file
 void KFountainSetup::readSettings()
 {
-	KConfig config("kssfountainrc", false, false);
+       KConfig config("kssfountainrc", KConfig::NoGlobals);
+       KConfigGroup grp = config.group("Settings");
 
-	config.setGroup( "Settings" );
-	QString boolval = config.readEntry( "Stars", "false" );
-	if (boolval == "true") {
-		RadioButton1->setDown(true);
-		RadioButton1_2->setDown(false);
+	bool boolval = grp.readEntry( "Stars", false );
+	if (boolval) {
+		RadioButton1->setChecked(true);
 	} else {
-		if (boolval == "false")
-		{
-			RadioButton1->setDown(false);
-			RadioButton1_2->setDown(true);
-		}
+			RadioButton1_2->setChecked(true);
 	}
 
-	QString starammount = config.readEntry("StarSize", "75");
-	SpinBox1->setValue(starammount.toInt());
+	int starammount = grp.readEntry("StarSize", 75);
+	SpinBox1->setValue(starammount);
 
 }
 
 // Ok pressed - save settings and exit
 void KFountainSetup::slotOkPressed()
 {
-	KConfig config("kssfountainrc", false, false);
-	config.setGroup( "Settings" );
+	KConfig _config("kssfountainrc", KConfig::NoGlobals);
+	KConfigGroup config(&_config, "Settings" );
 
-	if (RadioButton1->isOn() == true)
+	if (RadioButton1->isChecked() == true)
 	{
-		config.writeEntry( "Stars", "true" );
+		config.writeEntry( "Stars", true );
 	} else {
-		if (RadioButton1_2->isOn() == true)
+		if (RadioButton1_2->isChecked() == true)
 		{
-			config.writeEntry( "Stars", "false" );
+			config.writeEntry( "Stars", false );
 		}
 	}
-	config.writeEntry( "StarSize", QString::number(SpinBox1->value()) );
+	config.writeEntry( "StarSize", SpinBox1->value() );
 
 	config.sync();
 
@@ -149,16 +161,22 @@ void KFountainSetup::aboutPressed()
 KFountainSaver::KFountainSaver( WId id ) : KScreenSaver( id )
 {
 
-	kdDebug() << "Blank" << endl;
+	kDebug() << "Blank";
 
 	timer = new QTimer( this );
-    	timer->start( 25, TRUE );
-	setBackgroundColor( black );
-        erase();
+        timer->setSingleShot( true );
+        timer->start( 25 );
+        {
+            QPalette palette;
+            palette.setColor( backgroundRole(), Qt::black );
+            setPalette( palette );
+        }
+        update();
 	fountain = new Fountain();
 	embed(fountain);
 	fountain->show();
 	connect( timer, SIGNAL(timeout()), this, SLOT(blank()) );
+	show();
 }
 
 KFountainSaver::~KFountainSaver()
@@ -178,10 +196,11 @@ void KFountainSaver::blank()
 	// Play fountain
 
 	fountain->updateGL();
-	timer->start( 25, TRUE );
+    timer->setSingleShot(true);
+	timer->start( 25);
 
 }
-Fountain::Fountain( QWidget * parent, const char * name) : QGLWidget (parent,name)
+Fountain::Fountain( QWidget * parent ) : QGLWidget (parent)
 {
 	rainbow=true;
 	slowdown=2.0f;
@@ -191,20 +210,13 @@ Fountain::Fountain( QWidget * parent, const char * name) : QGLWidget (parent,nam
 	obj = gluNewQuadric();
 
 // This has to be here because you can't update the fountain until 'fountain' is created!
-	KConfig config("kssfountainrc", false, false);
-	config.setGroup( "Settings" );
-	QString boolval = config.readEntry( "Stars", "false" );
-	if (boolval == "true") {
-		setStars(true);
-	} else {
-		if (boolval == "false")
-		{
-			setStars(false);
-		}
-	}
+	KConfig _config("kssfountainrc", KConfig::NoGlobals);
+	KConfigGroup config(&_config, "Settings" );
+	bool boolval = config.readEntry( "Stars", false );
+        setStars(boolval);
 
-	QString starammount = config.readEntry("StarSize", "75");
-	float passvalue = (starammount.toInt() / 100.0);
+	int starammount = config.readEntry("StarSize", 75);
+	float passvalue = (starammount / 100.0);
 	setSize(passvalue);
 
 }
@@ -219,44 +231,44 @@ Fountain::~Fountain()
 bool Fountain::loadParticle()
 {
     /* Status indicator */
-    bool Status = TRUE;
-	QImage buf;
+    bool Status = true;
+    QImage buf;
 
-    kdDebug() << "Loading: " << locate("data", "kscreensaver/particle.png") << endl;
- if (buf.load( locate("data", "kscreensaver/particle.png") ) )
+    kDebug() << "Loading: " << KStandardDirs::locate("data", "kscreensaver/particle.png");
 
-        {
-		tex = convertToGLFormat(buf);  // flipped 32bit RGBA
-		kdDebug() << "Texture loaded: " << tex.numBytes () << endl;
-	}
-	else
-	{
-		QImage dummy( 32, 32, 32 );
-  		dummy.fill( Qt::white.rgb() );
-        	buf = dummy;
-		tex = convertToGLFormat( buf );
-	}
+    if (buf.load( KStandardDirs::locate("data", "kscreensaver/particle.png") ) )
+    {
+        tex = convertToGLFormat(buf);  // flipped 32bit RGBA
+        kDebug() << "Texture loaded: " << tex.numBytes ();
+    }
+    else
+    {
+        QImage dummy( 32, 32, QImage::Format_RGB32 );
+        dummy.fill( Qt::white );
+        buf = dummy;
+        tex = convertToGLFormat( buf );
+    }
 
-            /* Set the status to true */
-            //Status = TRUE;
-	glGenTextures(1, &texture[0]);   /* create three textures */
-	glBindTexture(GL_TEXTURE_2D, texture[0]);
-	/* use linear filtering */
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-	/* actually generate the texture */
-	glTexImage2D(GL_TEXTURE_2D, 0, 4, tex.width(), tex.height(), 0,
-	GL_RGBA, GL_UNSIGNED_BYTE, tex.bits());
+    /* Set the status to true */
+    //Status = true;
+    glGenTextures(1, &texture[0]);   /* create three textures */
+    glBindTexture(GL_TEXTURE_2D, texture[0]);
+    /* use linear filtering */
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+    /* actually generate the texture */
+    glTexImage2D(GL_TEXTURE_2D, 0, 4, tex.width(), tex.height(), 0,
+    GL_RGBA, GL_UNSIGNED_BYTE, tex.bits());
 
 
 
     return Status;
 }
-/** setup the GL enviroment */
+/** setup the GL environment */
 void Fountain::initializeGL ()
 {
 
-	kdDebug() << "InitGL" << endl;
+	kDebug() << "InitGL";
 	GLfloat colors[12][3]=
 	{{1.0f,0.5f,0.5f},{1.0f,0.75f,0.5f},{1.0f,1.0f,0.5f},{0.75f,1.0f,0.5f},
 	{0.5f,1.0f,0.5f},{0.5f,1.0f,0.75f},{0.5f,1.0f,1.0f},{0.5f,0.75f,1.0f},
@@ -296,13 +308,15 @@ void Fountain::initializeGL ()
 		{
 			particle[loop].active=true;				// Make All The Particles Active
 			particle[loop].life=1.0f;				// Give All The Particles Full Life
-			particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Speed
-			particle[loop].r=colors[(loop+1)/(MAX_PARTICLES/12)][0];	// Select Red Rainbow Color
-			particle[loop].g=colors[(loop+1)/(MAX_PARTICLES/12)][1];	// Select Green Rainbow Color
-			particle[loop].b=colors[(loop+1)/(MAX_PARTICLES/12)][2];	// Select Blue Rainbow Color
-			particle[loop].xi=float((KApplication::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
-			particle[loop].yi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
-			particle[loop].zi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
+			particle[loop].fade=float(KRandom::random()%100)/1000.0f+0.003f;	// Random Fade Speed
+			int color_index = (loop+1)/(MAX_PARTICLES/12);
+			color_index = qMin(11, color_index);
+			particle[loop].r=colors[color_index][0];	// Select Red Rainbow Color
+			particle[loop].g=colors[color_index][1];	// Select Green Rainbow Color
+			particle[loop].b=colors[color_index][2];	// Select Blue Rainbow Color
+			particle[loop].xi=float((KRandom::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
+			particle[loop].yi=float((KRandom::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
+			particle[loop].zi=float((KRandom::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
 			particle[loop].xg=0.0f;					// Set Horizontal Pull To Zero
 			particle[loop].yg=-0.8f;				// Set Vertical Pull Downward
 			particle[loop].zg=0.0f;					// Set Pull On Z Axis To Zero
@@ -315,7 +329,7 @@ void Fountain::initializeGL ()
 /** resize the gl view */
 void Fountain::resizeGL ( int width, int height )
 {
-	kdDebug() << "ResizeGL " << width << "," <<height<< endl;
+	kDebug() << "ResizeGL " << width << "," <<height;
 	if (height==0)							// Prevent A Divide By Zero By
 	{
 		height=1;						// Making Height Equal One
@@ -335,7 +349,7 @@ void Fountain::resizeGL ( int width, int height )
 /** paint the GL view */
 void Fountain::paintGL ()
 {
-	//kdDebug() << "PaintGL" << endl;
+	//kDebug() << "PaintGL";
 
 	GLfloat colors[12][3]=
 	{{1.0f,0.5f,0.5f},{1.0f,0.75f,0.5f},{1.0f,1.0f,0.5f},{0.75f,1.0f,0.5f},
@@ -401,13 +415,13 @@ void Fountain::paintGL ()
 			if (particle[loop].life<0.0f)					// If Particle Is Burned Out
 			{
 				particle[loop].life=2.0f;				// Give It New Life
-				particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Value
+				particle[loop].fade=float(KRandom::random()%100)/1000.0f+0.003f;	// Random Fade Value
 				particle[loop].x=0.0f;					// Center On X Axis
 				particle[loop].y=0.0f;					// Center On Y Axis
 				particle[loop].z=0.0f;					// Center On Z Axis
-				particle[loop].xi=xspeed+float((KApplication::random()%60)-32.0f);	// X Axis Speed And Direction
-				particle[loop].yi=yspeed+float((KApplication::random()%60)-30.0f);	// Y Axis Speed And Direction
-				particle[loop].zi=float((KApplication::random()%60)-30.0f);		// Z Axis Speed And Direction
+				particle[loop].xi=xspeed+float((KRandom::random()%60)-32.0f);	// X Axis Speed And Direction
+				particle[loop].yi=yspeed+float((KRandom::random()%60)-30.0f);	// Y Axis Speed And Direction
+				particle[loop].zi=float((KRandom::random()%60)-30.0f);		// Z Axis Speed And Direction
 				particle[loop].r=colors[col][0];			// Select Red From Color Table
 				particle[loop].g=colors[col][1];			// Select Green From Color Table
 				particle[loop].b=colors[col][2];			// Select Blue From Color Table
@@ -417,13 +431,15 @@ void Fountain::paintGL ()
 				// Explode
 					particle[loop].active=true;				// Make All The Particles Active
 					particle[loop].life=1.0f;				// Give All The Particles Full Life
-					particle[loop].fade=float(KApplication::random()%100)/1000.0f+0.003f;	// Random Fade Speed
-					particle[loop].r=colors[(loop+1)/(MAX_PARTICLES/12)][0];	// Select Red Rainbow Color
-					particle[loop].g=colors[(loop+1)/(MAX_PARTICLES/12)][1];	// Select Green Rainbow Color
-					particle[loop].b=colors[(loop+1)/(MAX_PARTICLES/12)][2];	// Select Blue Rainbow Color
-					particle[loop].xi=float((KApplication::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
-					particle[loop].yi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
-					particle[loop].zi=float((KApplication::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
+					particle[loop].fade=float(KRandom::random()%100)/1000.0f+0.003f;	// Random Fade Speed
+					int color_index = (loop+1)/(MAX_PARTICLES/12);
+					color_index = qMin(11, color_index);
+					particle[loop].r=colors[color_index][0];        // Select Red Rainbow Color
+					particle[loop].g=colors[color_index][1];        // Select Green Rainbow Color
+					particle[loop].b=colors[color_index][2];	// Select Blue Rainbow Color
+					particle[loop].xi=float((KRandom::random()%50)-26.0f)*10.0f;	// Random Speed On X Axis
+					particle[loop].yi=float((KRandom::random()%50)-25.0f)*10.0f;	// Random Speed On Y Axis
+					particle[loop].zi=float((KRandom::random()%50)-25.0f)*10.0f;	// Random Speed On Z Axis
 					particle[loop].xg=0.0f;					// Set Horizontal Pull To Zero
 					particle[loop].yg=-0.8f;				// Set Vertical Pull Downward
 					particle[loop].zg=0.0f;					// Set Pull On Z Axis To Zero
